package com.yanzhu.jh.project.service;

import java.util.List;
import com.yanzhu.jh.project.domain.SurProjectInvest;

/**
 * 项目投资Service接口
 * 
 * @author JiangYuQi
 * @date 2023-07-29
 */
public interface ISurProjectInvestService 
{
    /**
     * 查询项目投资
     * 
     * @param id 项目投资主键
     * @return 项目投资
     */
    public SurProjectInvest selectSurProjectInvestById(Long id);

    /**
     * 查询项目投资列表
     * 
     * @param surProjectInvest 项目投资
     * @return 项目投资集合
     */
    public List<SurProjectInvest> selectSurProjectInvestList(SurProjectInvest surProjectInvest);

    /**
     * 新增项目投资
     * 
     * @param surProjectInvest 项目投资
     * @return 结果
     */
    public int insertSurProjectInvest(SurProjectInvest surProjectInvest);

    /**
     * 修改项目投资
     * 
     * @param surProjectInvest 项目投资
     * @return 结果
     */
    public int updateSurProjectInvest(SurProjectInvest surProjectInvest);

    /**
     * 批量删除项目投资
     * 
     * @param ids 需要删除的项目投资主键集合
     * @return 结果
     */
    public int deleteSurProjectInvestByIds(Long[] ids);

    /**
     * 删除项目投资信息
     * 
     * @param id 项目投资主键
     * @return 结果
     */
    public int deleteSurProjectInvestById(Long id);
}
